## Version:1.0.0-alpha.7 -- 25 Mar 2026

* Adds compatibility for engine versions 5.6 and 5.7
* Enhanced logging capabilities for P4Utils

## Version:1.0.0-alpha.6 -- 12 Feb 2026

* Warns user of jobs with no active shots in the Movie Render Queue
* Addition of developer script to aid with FAB Marketplace submissions

## Version:1.0.0-alpha.5 -- 9 Jan 2026

* Checks Perforce Enabled flag before rendering the Movie Render Queue

## Version:1.0.0-alpha.4 -- 29 Oct 2025

* Updated dependencies

## Version:1.0.0-alpha.3 -- 25 Sept 2025

* Added Username and Password fields to plugin's Perforce section for improved convenience

## Version:1.0.0-alpha.2 -- 25 Sept 2025

* Reduction of miscellaneous warnings and errors to improve the user experience
* Added developer tool for enhanced logging at various log levels
* Updated Perforce workspace cleanup command to grant execution permission for write-level users and above
* Updated README with documentation links, updated .gitignore to enhance developer testing

## Version:1.0.0-alpha.1 -- 4 June 2025

* Versioning for public plugin release

## Version:0.1.5 -- 27 May 2025

* Additional formatting for upload time statistics so text does not overflow

## Version:0.1.4 -- 27 May 2025

* Ensures multi-job submission data is accurate by populating the Manifest Queue at upload time

## Version:0.1.3 -- 16 May 2025

* Submit only enabled Movie Render Queue Jobs for rendering

## Version:0.1.2 -- 14 May 2025

*  Ensure render execution by filtering and submitting to only Windows instances

## Version:0.1.1 -- 21 Mar 2025

*  Supports plugin installation through the Conductor Companion App

## Version:0.1.0 -- 15 Jan 2025

*  Ensure Unreal render engine compatibility by only displaying single GPU instance types